<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nb">
<context>
    <name>MEConfig</name>
    <message>
        <location filename="../mainwindow.ui" line="26"/>
        <source>MX User Manager</source>
        <translation>MX Brukeradministrasjon</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="62"/>
        <source>Administration</source>
        <translation>Administrasjon</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="65"/>
        <source>Add a new user</source>
        <translation>Legg til ny bruker</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="105"/>
        <source>Add User Account</source>
        <translation>Legg til brukerkonto</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="132"/>
        <source>Reenter password for new user</source>
        <translation>Skriv passord til ny bruker om igjen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="141"/>
        <source>confirm password</source>
        <translation>bekreft passord</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="157"/>
        <source>Username of new user</source>
        <translation>Ny brukers brukernavn</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="160"/>
        <source>User login name:</source>
        <translation>Brukerens innloggingsnavn:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="176"/>
        <location filename="../mainwindow.ui" line="456"/>
        <source>Enter username of new user</source>
        <translation>Skriv inn ny brukers brukernavn</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="182"/>
        <location filename="../mainwindow.ui" line="462"/>
        <source>username</source>
        <translation>brukernavn</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="198"/>
        <location filename="../mainwindow.ui" line="242"/>
        <source>Password for new user</source>
        <translation>Ny brukers passord</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="201"/>
        <source>User password:</source>
        <translation>Brukers passord:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="217"/>
        <source>Enter password for new user</source>
        <translation>Skriv inn ny brukers passord</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="226"/>
        <source>password</source>
        <translation>passord</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="245"/>
        <source>Confirm user password:</source>
        <translation>Bekreft brukerpassord:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="280"/>
        <source>Delete User Account</source>
        <translation>Slett brukerkonto</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="323"/>
        <source>Select user</source>
        <translation>Velg bruker</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="339"/>
        <location filename="../mainwindow.ui" line="1426"/>
        <source>Select user to delete</source>
        <translation>Velg bruker som skal slettes</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="348"/>
        <source>User to delete:</source>
        <translation>Slett denne brukeren:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="364"/>
        <source>Also delete the user&apos;s home directory</source>
        <translation>Slett også brukerens hjemmemappe</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="367"/>
        <source>Delete user home directory</source>
        <translation>Slett brukers hjemmemappe</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="386"/>
        <source>Rename User Account</source>
        <translation>Endre brukerkontoens navn</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="398"/>
        <location filename="../mainwindow.ui" line="560"/>
        <source>Select user to modify:</source>
        <translation>Endre denne brukeren:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="440"/>
        <source>New user name:</source>
        <translation>Nytt brukernavn:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="481"/>
        <source>Change User Password</source>
        <translation>Endre brukers passord</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="509"/>
        <source>new password</source>
        <translation>nytt passord</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="525"/>
        <source>Confirm new password:</source>
        <translation>Bekreft nytt passord:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="544"/>
        <source>confirm new password</source>
        <translation>bekreft nytt passord</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="576"/>
        <source>New user password:</source>
        <translation>Nytt brukerpassord:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="610"/>
        <source>Options</source>
        <translation>Alternativer</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="613"/>
        <source>Repair a user configuration</source>
        <translation>Reparer brukeroppsett</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="647"/>
        <location filename="../mainwindow.ui" line="1383"/>
        <source>Modify User Account</source>
        <translation>Endre brukerkonto</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="659"/>
        <location filename="../mainwindow.ui" line="675"/>
        <source>Select user to repair</source>
        <translation>Reparer denne brukeren</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="662"/>
        <location filename="../mainwindow.ui" line="1435"/>
        <source>User to change:</source>
        <translation>Endre denne brukeren:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="707"/>
        <source>Restore Defaults</source>
        <translation>Gjenopprett til forvalg</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="728"/>
        <source>Restore browser configs to MX defaults</source>
        <translation>Gjenopprett oppsett av nettleser til MXs forvalg</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="734"/>
        <source>Mozilla (Iceweasel or Firefox) configs</source>
        <translation>Oppsett av Mozilla (Iceweasel eller Firefox)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="737"/>
        <source>Alt+X</source>
        <translation>Alt + X</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="744"/>
        <source>Restore group memberships to MX defaults</source>
        <translation>Gjenopprett gruppemedlemskap til MXs forvalg</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="750"/>
        <source>Group memberships</source>
        <translation>Gruppemedlemskap</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="753"/>
        <source>Alt+G</source>
        <translation>Alt + G</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="763"/>
        <source>Change Autologin Settings</source>
        <translation>Endre automatisk innlogging</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="769"/>
        <source>Log in automatically</source>
        <translation>Logg inn automatisk</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="776"/>
        <source>Require password to log in</source>
        <translation>Krev innloggingspassord</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="791"/>
        <source>Copy/Sync</source>
        <translation>Kopier/synkroniser</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="818"/>
        <source>Copy Between Desktops</source>
        <translation>Kopier mellom skrivebord</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="845"/>
        <location filename="../mainwindow.ui" line="912"/>
        <source>Select desktop to copy from</source>
        <translation>Kopier fra dette skrivebordet</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="858"/>
        <source>Select to only copy files</source>
        <translation>Kopier kun filer</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="861"/>
        <source>Copy only</source>
        <translation>Kun kopiering</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="877"/>
        <location filename="../mainwindow.ui" line="890"/>
        <source>Select desktop to copy to</source>
        <translation>Kopier til dette skrivebordet</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="899"/>
        <source>Copy to:</source>
        <translation>Kopier til:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="921"/>
        <source>Copy from:</source>
        <translation>Kopier fra:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="934"/>
        <source>Select to copy and then delete differences</source>
        <translation>Kopier og deretter slett forskjeller</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="937"/>
        <source>Sync</source>
        <translation>Synkroniser</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="983"/>
        <source>Select to copy/sync Shared</source>
        <translation>Kopier/synkroniser delte</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="986"/>
        <source>Shared folder</source>
        <translation>Delt mappe</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="999"/>
        <source>Select to copy/sync entire home</source>
        <translation>Kopier/synkroniser hele hjemmemappa</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1002"/>
        <source>Entire home</source>
        <translation>Hele hjemmemappa</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1018"/>
        <source>Select to copy/sync the browser configuration</source>
        <translation>Kopier/synkroniser nettleseroppsettet</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1021"/>
        <source>Mozilla (Firefox or Iceweasel) configs</source>
        <translation>Oppsett av Mozilla (Iceweasel eller Firefox)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1034"/>
        <source>Select to copy/sync Documents</source>
        <translation>Kopier/synkroniser dokumenter</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1037"/>
        <source>Documents folder</source>
        <translation>Dokumentmappa</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1044"/>
        <source>What to copy/sync:</source>
        <translation>Hva som skal kopieres/synkroniseres:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1060"/>
        <source>Progress</source>
        <translation>Framdrift</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1090"/>
        <location filename="../mainwindow.ui" line="1106"/>
        <source>Status of the changes</source>
        <translation>Endringenes status</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1109"/>
        <source>Status:</source>
        <translation>Status:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1125"/>
        <source>Progress of the changes</source>
        <translation>Endringenes framdrift</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1162"/>
        <source>Add/Remove Groups</source>
        <translation>Legg til/fjern grupper</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1174"/>
        <source>Add Group</source>
        <translation>Legg til gruppe</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;br/&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="vanished">&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;br/&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1252"/>
        <source>Group name:</source>
        <translation>Gruppenavn:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1201"/>
        <source>Enter name of new group</source>
        <translation>Skriv inn gruppenavnet</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1207"/>
        <source>groupname</source>
        <translation>gruppenavn</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1271"/>
        <source>Delete Group</source>
        <translation>Slett gruppe</translation>
    </message>
    <message>
        <source>Select group to delete</source>
        <translation type="vanished">Velg gruppe som skal slettes</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1340"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Select group to delete&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Velg gruppe som skal slettes&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>Group to delete:</source>
        <translation type="vanished">Slett denne gruppa:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1371"/>
        <source>Group Membership</source>
        <translation>Gruppemedlemskap</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1497"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Select user to change&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Velg bruker som skal endres&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1445"/>
        <source>Groups user belongs to (change the groups by selecting/deselecting the appropriate boxes):</source>
        <translation>Hvilke grupper som brukeren tilhører (bruk avkryssingsboksene for å velge eller fravelge grupper)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1468"/>
        <source>*Please doublecheck your selections before applying, assigning wrong group memberships can break your system. If you made a mistake, use restore group membership in Options tab to restore the defaults.</source>
        <translation>*Dobbeltsjekk valgte endringer før de tas i bruk. Tilordning av feil gruppemedlemskap kan skade systemet. Hvis noe går galt så kan de forvalgte gruppemedlemskapene gjenopprettes under fanen «Alternativer».</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1641"/>
        <source>Apply any changes</source>
        <translation>Ta i bruk endringene</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1644"/>
        <source>Apply</source>
        <translation>Bruk</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1651"/>
        <source>Alt+A</source>
        <translation>Alt + A</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1573"/>
        <source>Cancel any changes then quit</source>
        <translation>Forkast alle endringer og avslutt</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1217"/>
        <source>Create a group with GID &gt; 1000</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1220"/>
        <source>Create a user-level group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1249"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Enter name of new group&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1349"/>
        <source>Select group to delete:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1356"/>
        <source>*Please doublecheck your selections before applying, removing a wrong group can break your system.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1576"/>
        <source>Close</source>
        <translation>Lukk</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1583"/>
        <source>Alt+N</source>
        <translation>Alt + N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1624"/>
        <source>Display help </source>
        <translation>Vis hjelp</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1627"/>
        <source>Help</source>
        <translation>Hjelp</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1634"/>
        <source>Alt+H</source>
        <translation>Alt + H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1658"/>
        <source>About this application</source>
        <translation>Om programmet</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1661"/>
        <source>About...</source>
        <translation>Om …</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1668"/>
        <source>Alt+B</source>
        <translation>Alt + B</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="110"/>
        <location filename="../mainwindow.cpp" line="154"/>
        <location filename="../mainwindow.cpp" line="162"/>
        <location filename="../mainwindow.cpp" line="180"/>
        <location filename="../mainwindow.cpp" line="189"/>
        <location filename="../mainwindow.cpp" line="197"/>
        <location filename="../mainwindow.cpp" line="664"/>
        <location filename="../mainwindow.cpp" line="688"/>
        <location filename="../mainwindow.cpp" line="715"/>
        <location filename="../mainwindow.cpp" line="869"/>
        <location filename="../mainwindow.cpp" line="970"/>
        <location filename="../mainwindow.cpp" line="976"/>
        <location filename="../mainwindow.cpp" line="981"/>
        <location filename="../mainwindow.cpp" line="984"/>
        <location filename="../mainwindow.cpp" line="986"/>
        <source>none</source>
        <translation>ingen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="140"/>
        <location filename="../mainwindow.cpp" line="651"/>
        <location filename="../mainwindow.cpp" line="875"/>
        <location filename="../mainwindow.cpp" line="883"/>
        <source>browse...</source>
        <translation>bla …</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="206"/>
        <source>The user configuration will be repaired. Please close all other applications now. When finished, please logout or reboot. Are you sure you want to repair now?</source>
        <translation>Brukerens oppsett vil nå bli reparert. Lukk alle andre programmer før du fortsetter. Du må logge ut eller omstarte maskinen etterpå. Vil du fortsette reparasjonen nå?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="228"/>
        <source>User group membership was restored.</source>
        <translation>Gjenopprettet brukerens gruppemedlemskap.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="234"/>
        <source>Mozilla settings were reset.</source>
        <translation>Gjenopprettet oppsettet av Mozilla.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="243"/>
        <location filename="../mainwindow.cpp" line="254"/>
        <source>Autologin options</source>
        <translation>Alternativer for autoinnlogging</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="244"/>
        <source>Autologin has been disabled for the &apos;%1&apos; account.</source>
        <translation>Autoinnlogging er slått av for kontoen «%1».</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="255"/>
        <source>Autologin has been enabled for the &apos;%1&apos; account.</source>
        <translation>Autoinnlogging er slått på for kontoen «%1».</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="267"/>
        <source>You must specify a &apos;copy to&apos; destination. You cannot copy to the desktop you are logged in to.</source>
        <translation>Velg et mål for kopieringen. Man kan ikke kopiere til det skrivebordet man er logget inn i.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="274"/>
        <source>Before copying, close all other applications. Be sure the copy to destination is large enough to contain the files you are copying. Copying between desktops may overwrite or delete your files or preferences on the destination desktop. Are you sure you want to proceed?</source>
        <translation>Lukk alle andre programmer før kopiering. Sørg for at målet har nok plass til filene som skal kopieres. Kopiering mellom skrivebord kan overskrive eller slette filer og innstillinger i skrivebordet det kopieres til. Vil du fortsette?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="298"/>
        <source>Synchronizing desktop...</source>
        <translation>Synkroniserer skrivebord …</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="300"/>
        <source>Copying desktop...</source>
        <translation>Kopierer skrivebord …</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="328"/>
        <location filename="../mainwindow.cpp" line="521"/>
        <source>The user name needs to be at least 2 characters long. Please select a longer name before proceeding.</source>
        <translation>Brukernavnet må være minst to tegn langt. Velg et lengre navn.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="332"/>
        <source>The user name cannot contain special characters or spaces.
Please choose another name before proceeding.</source>
        <translation>Brukernavnet kan ikke inneholde spesialtegn eller mellomrom.
Velg et annet brukernavn.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="339"/>
        <source>Sorry, this name is in use. Please enter a different name.</source>
        <translation>Brukernavnet er allerede i bruk. Velg et annet brukernavn.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="343"/>
        <location filename="../mainwindow.cpp" line="375"/>
        <source>Password entries do not match. Please try again.</source>
        <translation>Ikke samsvar mellom oppgitte passord. Forsøk igjen.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="349"/>
        <location filename="../mainwindow.cpp" line="381"/>
        <source>Password needs to be at least 2 characters long. Please enter a longer password before proceeding.</source>
        <translation>Passordet må være minst to tegn langt. Velg et lengre passord.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="364"/>
        <source>The user was added ok.</source>
        <translation>Ny bruker lagt til.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="367"/>
        <source>Failed to add the user.</source>
        <translation>Klarte ikke legge til bruker.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="393"/>
        <source>Password successfully changed.</source>
        <translation>Passord endret.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="396"/>
        <source>Failed to change password.</source>
        <translation>Klarte ikke endret.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="402"/>
        <source>This action cannot be undone. Are you sure you want to delete user %1?</source>
        <translation>Denne handlingen kan ikke angres. Vil du slette brukeren %1? </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="413"/>
        <source>The user has been deleted.</source>
        <translation>Brukeren er nå slettet.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="415"/>
        <source>Failed to delete the user.</source>
        <translation>Klarte ikke slette brukeren.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="428"/>
        <source>The group name needs to be at least 2 characters long. Please select a longer name before proceeding.</source>
        <translation>Gruppenavnet må være minst to tegn langt. Velg et lengre navn.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="433"/>
        <source>The group name needs to be lower case and it 
cannot contain special characters or spaces.
Please choose another name before proceeding.</source>
        <translation>Gruppenavnet må være i små bokstaver og det
kan ikke inneholde spesialtegn eller mellomrom.
Velg et annet gruppenavn.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="441"/>
        <source>Sorry, that group name already exists. Please enter a different name.</source>
        <translation>Gruppenavnet er allerede i bruk. Velg et annet gruppenavn.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="449"/>
        <source>The system group was added ok.</source>
        <translation>Ny gruppe lagt til.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="451"/>
        <source>Failed to add the system group.</source>
        <translation>Klarte ikke legge til gruppe.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="464"/>
        <source>This action cannot be undone. Are you sure you want to delete group %1?</source>
        <translation>Denne handlingen kan ikke angres. Vil du slette gruppa %1?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="467"/>
        <source>This action cannot be undone. Are you sure you want to delete the following groups: %1?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="474"/>
        <source>Group: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="479"/>
        <source>The group has been deleted.</source>
        <translation>Gruppa er nå slettet.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="474"/>
        <source>Failed to delete the group.</source>
        <translation>Klarte ikke slette gruppa.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="479"/>
        <source>The groups have been deleted.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="496"/>
        <source>The changes have been applied.</source>
        <translation>Endringene er nå tatt i bruk.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="498"/>
        <source>Failed to apply group changes</source>
        <translation>Klarte ikke ta i bruk gruppe-endringene</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="511"/>
        <source>The selected user name is currently in use.</source>
        <translation>Den valgte brukerkontoen er i aktiv bruk.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="512"/>
        <source>To rename this user, please log out and log back in using another user account.</source>
        <translation>Logg ut og logg inn med en annen brukerkonto for å endre navnet til denne brukerkontoen.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="525"/>
        <source>The user name needs to be lower case and it
cannot contain special characters or spaces.
Please choose another name before proceeding.</source>
        <translation>Brukernavnet må være i små bokstaver og det
kan ikke inneholde spesialtegn eller mellomrom.
Velg et annet brukernavn.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="534"/>
        <source>Sorry, this name already exists on your system. Please enter a different name.</source>
        <translation>Dette navnet finnes allerede på systemet. Velg et annet navn.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="542"/>
        <source>Failed to rename the user. Please make sure that the user is not logged in, you might need to restart</source>
        <translation>Klarte ikke endre brukernavn. Sørg for at brukeren ikke er logget inn. Det kan være nødvendig med en omstart.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="564"/>
        <source>The user was renamed.</source>
        <translation>Brukernavnet ble endret.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="576"/>
        <location filename="../mainwindow.cpp" line="605"/>
        <source>Synchronizing desktop...ok</source>
        <translation>Synkroniserer skrivebord … ferdig.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="578"/>
        <location filename="../mainwindow.cpp" line="607"/>
        <source>Copying desktop...ok</source>
        <translation>Kopierer skrivebord … ferdig.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="610"/>
        <source>Synchronizing desktop...failed</source>
        <translation>Synkroniserer skrivebord … mislyktes.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="612"/>
        <source>Copying desktop...failed</source>
        <translation>Kopierer skrivebord … mislyktes.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="629"/>
        <source>Confirmation</source>
        <translation>Bekreft</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="630"/>
        <source>Process not done. Are you sure you want to quit the application?</source>
        <translation>Prosessen er ikke fullført. Vil du virkelig avslutte dette programmet?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="835"/>
        <source>About %1</source>
        <translation>Om %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="836"/>
        <source>Version: </source>
        <translation>Versjon:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="837"/>
        <source>Simple user configuration for MX Linux</source>
        <translation>Verktøy for brukeroppsett i MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="839"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Opphavsrett (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="840"/>
        <source>%1 License</source>
        <translation>Lisens for %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="854"/>
        <source>%1 Help</source>
        <translation>Hjelpetekst for %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="876"/>
        <source>Select folder to copy to</source>
        <translation>Kopier til denne mappa</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="52"/>
        <source>License</source>
        <translation>Lisens</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="53"/>
        <location filename="../about.cpp" line="62"/>
        <source>Changelog</source>
        <translation>Endringslogg</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="54"/>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="74"/>
        <source>&amp;Close</source>
        <translation>&amp;Lukk</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="58"/>
        <source>Error</source>
        <translation>Feil</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="59"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Du er innlogget som root. Vennligst logg ut, og logg inn igjen som en vanlig bruker for å bruke dette programmet.</translation>
    </message>
</context>
</TS>
